<?php

namespace Superrobota\Benefit\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Benefit\Models\Benefit;

class BenefitPolicy
{

    /**
     * Determine if the given user can view the benefit.
     *
     * @param UserPolicy $user
     * @param Benefit $benefit
     *
     * @return bool
     */
    public function view(UserPolicy $user, Benefit $benefit)
    {
        if ($user->canDo('benefit.benefit.view') && $user->isAdmin()) {
            return true;
        }

        return $benefit->user_id == user_id() && $benefit->user_type == user_type();
    }

    /**
     * Determine if the given user can create a benefit.
     *
     * @param UserPolicy $user
     * @param Benefit $benefit
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('benefit.benefit.create');
    }

    /**
     * Determine if the given user can update the given benefit.
     *
     * @param UserPolicy $user
     * @param Benefit $benefit
     *
     * @return bool
     */
    public function update(UserPolicy $user, Benefit $benefit)
    {
        if ($user->canDo('benefit.benefit.edit') && $user->isAdmin()) {
            return true;
        }

        return $benefit->user_id == user_id() && $benefit->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given benefit.
     *
     * @param UserPolicy $user
     * @param Benefit $benefit
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Benefit $benefit)
    {
        return $benefit->user_id == user_id() && $benefit->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given benefit.
     *
     * @param UserPolicy $user
     * @param Benefit $benefit
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Benefit $benefit)
    {
        if ($user->canDo('benefit.benefit.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given benefit.
     *
     * @param UserPolicy $user
     * @param Benefit $benefit
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Benefit $benefit)
    {
        if ($user->canDo('benefit.benefit.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
