<?php

namespace Superrobota\Benefit\Providers;

use Illuminate\Support\ServiceProvider;

class BenefitServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'benefit');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'benefit');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('superrobota.benefit', function ($app) {
            return $this->app->make('Superrobota\Benefit\Benefit');
        });

                // Bind Benefit to repository
        $this->app->bind(
            'Superrobota\Benefit\Interfaces\BenefitRepositoryInterface',
            \Superrobota\Benefit\Repositories\Eloquent\BenefitRepository::class
        );

        $this->app->register(\Superrobota\Benefit\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Superrobota\Benefit\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['superrobota.benefit'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('superrobota/benefit.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/benefit')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/benefit')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
